@@ -6,16 +6,17 @@
 
 #pragma once
 
+#include <QAction>
 #include <QObject>
 #include <QPointer>
 #include <QQuickItem>
 #include <QUrl>
-
-class QAction;
+#include <qqmlregistration.h>
 
 class NotificationFileMenu : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
     Q_PROPERTY(QUrl url READ url WRITE setUrl NOTIFY urlChanged)
     Q_PROPERTY(QQuickItem *visualParent READ visualParent WRITE setVisualParent NOTIFY visualParentChanged)
     Q_PROPERTY(bool visible READ visible WRITE setVisible NOTIFY visibleChanged)
