@@ -28,6 +28,11 @@ ScreenRotationUtil::ScreenRotationUtil(QObject *parent)
 
     connect(new KScreen::GetConfigOperation(), &KScreen::GetConfigOperation::finished, this, [this](auto *op) {
         m_config = qobject_cast<KScreen::GetConfigOperation *>(op)->config();
+        if (!m_config) {
+            qDebug() << "screenrotationutil: Unable to obtain kscreen config";
+            return;
+        }
+
         KScreen::ConfigMonitor::instance()->addConfig(m_config);
 
         // update all screens with event connect
